<?php
/*
* $Id: cm_sc_order_total.php
* $Loc: /includes/modules/content/shopping_cart/
*
* Name: ShipInCart
* Version: 6.4
* Release Date: 2024-07-22
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under the GNU General Public License
*
* Comments: Author: [Rainer Schmied @raiwa]
* Author URI: [www.phoenixcartaddons.com]
* 
* CE Phoenix, E-Commerce made Easy
* https://phoenixcart.org
* 
* Copyright (c) 2021 Phoenix Cart
* 
* 
*/

  class cm_sc_order_total extends abstract_executable_module {

    const CONFIG_KEY_BASE = 'MODULE_CONTENT_SC_ORDER_TOTAL_';

    public function __construct() {
      parent::__construct(__FILE__);
    }

    function execute() {
      global $order;

      if (($_SESSION['cart']->count_contents() > 0)) {
        // BOF get taxes if not logged in
        if ( !isset($_SESSION['customer_id']) ) { //guest
          if ( $_SESSION['cart']->get_content_type() == 'virtual') {
            $order = new order;
            $country_info = Country::fetch(STORE_COUNTRY);
            $order->billing = ['zone_id' => STORE_ZONE,
                               'country' => ['id' => STORE_COUNTRY, 'title' => $country_info['countries_name'], 'iso_code_2' => $country_info['countries_iso_code_2'], 'iso_code_3' =>  $country_info['countries_iso_code_3']],
                            'country_id' => STORE_COUNTRY,
                    ];
            $order->delivery = ['zone_id' => STORE_ZONE,
                               'country' => ['id' => STORE_COUNTRY, 'title' => $country_info['countries_name'], 'iso_code_2' => $country_info['countries_iso_code_2'], 'iso_code_3' =>  $country_info['countries_iso_code_3']],
                            'country_id' => STORE_COUNTRY,
                    ];
          } elseif ( (defined('MODULE_CONTENT_SC_SHIPPING_STATUS') && MODULE_CONTENT_SC_SHIPPING_STATUS == 'True') 
                   || defined('MODULE_CONTENT_SC_TWOPAGE_SHIPPING_STATUS') && MODULE_CONTENT_SC_TWOPAGE_SHIPPING_STATUS == 'True') {
            $products = $_SESSION['cart']->get_products();
            foreach ($products as $product) {
              $products_tax = Tax::get_rate($product->get('tax_class_id'), $order->delivery['country_id'], $order->delivery['zone_id']);
              $products_tax_description = Tax::get_description($product->get('tax_class_id'), $order->delivery['country_id'], $order->delivery['zone_id']);
              if ( DISPLAY_PRICE_WITH_TAX == 'true' ) {
                //Modified by Strider 42 to correct the tax calculation when a customer is not logged in
                $tax_val = (($product->format_raw('final_price', $product->get('quantity'))/100)*$products_tax);
              } else {
                $tax_val = (($product->format_raw('final_price', $product->get('quantity'))*$products_tax)/100);
              }
              if ( !empty($order->info['tax']) ) {
                $order->info['tax'] += $tax_val;
              } else {
                $order->info['tax'] = $tax_val;
              }
              if ( !empty($order->info['tax_groups']) ) {
                $module = substr($_SESSION['shipping']['id'], 0, strpos($_SESSION['shipping']['id'], '_'));
                if (isset($order->info['shipping_method'])) {
                  if (($GLOBALS[$module]->tax_class ?? 0) > 0) {
                    $shipping_tax = Tax::get_rate($GLOBALS[$module]->tax_class, $order->delivery['country']['id'], $order->delivery['zone_id']);
                    $shipping_tax_description = Tax::get_description($GLOBALS[$module]->tax_class, $order->delivery['country']['id'], $order->delivery['zone_id']);

                    $order->info['tax'] += Tax::calculate($order->info['shipping_cost'], $shipping_tax);
                    if (!isset($order->info['tax_groups']["$shipping_tax_description"])) {
                      Guarantor::guarantee_subarray($order->info, 'tax_groups')["$shipping_tax_description"] = 0;
                    }
                    $order->info['tax_groups']["$shipping_tax_description"] += Tax::calculate($order->info['shipping_cost'], $shipping_tax);
                    $order->info['total'] += Tax::calculate($order->info['shipping_cost'], $shipping_tax);

                    if (DISPLAY_PRICE_WITH_TAX == 'true') {
                      $order->info['shipping_cost'] += Tax::calculate($order->info['shipping_cost'], $shipping_tax);
                    }
                  }
                }
                if (!isset($order->info['tax_groups']["$products_tax_description"])) {
                  Guarantor::guarantee_subarray($order->info, 'tax_groups')["$products_tax_description"] = 0;
                }
                $order->info['tax_groups']["$products_tax_description"] += $tax_val;
              } else {
                $order->info['tax_groups']["$products_tax_description"] = $tax_val;
              }

              // Modified by Strider 42 to correct the order total figure when shop displays prices with tax
              if ( DISPLAY_PRICE_WITH_TAX == 'true' ) {
                $order->info['total'];
              } else {
                $order->info['total']+= $tax_val;
              }
            }
          } else {
            $country_info = Country::fetch(STORE_COUNTRY);
            $order->billing = ['zone_id' => STORE_ZONE,
                               'country' => ['id' => STORE_COUNTRY, 'title' => $country_info['countries_name'], 'iso_code_2' => $country_info['countries_iso_code_2'], 'iso_code_3' =>  $country_info['countries_iso_code_3']],
                               'country_id' => STORE_COUNTRY
                              ];
          }
        } else {
          $order = new order;
        }

        // EOF get taxes if not logged in (seems like less code than in order class)
        $order_total_modules = new order_total;
        $order_total_modules->process();

        if ( !isset($_SESSION['customer_id']) ) { //guest
          unset($_SESSION['billto']);
        }

        if ( MODULE_ORDER_TOTAL_INSTALLED ) {

          $tpl_data = [ 'group' => $this->group, 'file' => __FILE__ ];
          include 'includes/modules/content/cm_template.php';
        }
      }
    }

    protected function get_parameters() {
      return [
         $this->config_key_base . 'VERSION' => [
          'title' => 'Current Version',
          'value' => '6.4',
          'desc' => 'Version info. It is read only',
          'set_func' => 'cm_sc_order_total::readonly(',
        ],
        $this->config_key_base . 'STATUS' => [
          'title' => 'Enable Order Total Module',
          'value' => 'True',
          'desc' => 'Do you want to add the module to your shop?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'CONTENT_WIDTH' => [
          'title' => 'Content Container',
          'value' => 'col-sm-12',
          'desc' => 'What container should the content be shown in? (col-*-12 = full width, col-*-6 = half width).',
        ],
        $this->config_key_base . 'SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '1000',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
      ];
    }

    public static function readonly($value) {
      return $value;
    }

  }
